/** \file sparam_function.cpp
*   \brief サーバに関するバインド用ファイル
*   \auther Shun.E
*/
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <iostream>

#include <rcsc/action/basic_actions.h>
#include <rcsc/player/player_agent.h>
#include <rcsc/player/debug_client.h>

#include <rcsc/common/audio_memory.h>
#include <rcsc/common/logger.h>
#include <rcsc/common/server_param.h>

#include "sparam_function.h"
#include "izk_main.h"

using namespace luabind;
using namespace rcsc;

/** \fn l_getBallSize()
*   \brief 現在のボールさイズをサーバから取得する
*   \return ボールサイズ
*/
double 
l_getBallSize()
{
    return ServerParam::i().ballSize();
}

/** \fn l_getPower()
*   \brief サーバで用意された最大のパワーを取得する
*   \return サーバで用意された最大のパワー
*/
double
l_getPower()
{
    return ServerParam::i().maxPower();
}


/** \fn l_maxNeckAngle()
*   \brief アングル最大値取得
*   \return アングル最大値
*/
double
l_maxNeckAngle()
{
    // アングルの最大値
    return ServerParam::i().maxNeckAngle();
}

/** \fn l_oppGoalPosX()
*   \brief 敵チームのゴールX座標取得
*   \return 敵チームのゴールX座標
*/
double
l_oppGoalPosX()
{
    return  ServerParam::i().theirTeamGoalPos().x;
}

/** \fn l_oppGoalPosY()
*   \brief 敵チームのゴールY座標取得
*   \return 敵チームのゴールY座標
*/
double
l_oppGoalPosY()
{
    return ServerParam::i().theirTeamGoalPos().y;
}

double
l_pitchHalfLength()
{
    return ServerParam::i().pitchHalfLength();
}

double
l_getcenterCircleR()
{
    return ServerParam::i().centerCircleR();
}

double
l_getgoalHalfWidth()
{
    return ServerParam::i().goalHalfWidth();
}

/** \fn l_getcatchableArea()
*   \brief キャッチ可能なライン
*   \return キャッチ可能なライン
*/
double 
l_getcatchableArea()
{
    return ServerParam::i().catchableArea();
}

/** \fn l_ourPenaltyAreaLineX()
*   \brief 味方のペナルティエリアのX座標
*   \return 味方のペナルティエリアのX座標
*/
double 
l_ourPenaltyAreaLineX()
{
    return ServerParam::i().ourPenaltyAreaLineX();
}

/** \fn l_iskickoffOffside()
*   \brief 敵のペナルティエリアのX座標取得
*   \return 敵のペナルティエリアのX座標
*/
double
l_theirPenaltyAreaLineX()
{
    return ServerParam::i().theirPenaltyAreaLineX();
}

/** \fn l_iskickoffOffside()
*   \brief オフサイドかどうか取得
*   \return オフサイド判定
*/
double
l_penaltyAreaHalfWidth()
{
    return ServerParam::i().penaltyAreaHalfWidth();
}

/** \fn l_iskickoffOffside()
*   \brief オフサイドかどうか取得
*   \return オフサイド判定
*/
bool
l_iskickoffOffside()
{
    return ServerParam::i().kickoffOffside();
}

/** \fn l_getHalfTime()
*   \brief ハーフタイム取得
*   \return ハーフタイム
*/
int
l_getHalfTime()
{
    return ServerParam::i().halfTime();
}

/** \fn l_getExtraHalfTime()
*   \brief 延長戦のハーフタイム取得
*   \return 延長戦のハーフタイム
*/
int
l_getExtraHalfTime()
{
    return ServerParam::i().extraHalfTime();
}

/** \fn l_getnrNormalHalfs()
*   \brief 通常ハーフタイム取得
*   \return 通常ハーフタイム
*/
int
l_getnrNormalHalfs()
{
    return ServerParam::i().nrNormalHalfs();
}

/** \fn l_getnrNormalHalfs()
*   \brief 延長戦の通常ハーフタイム取得
*   \return 延長戦の通常ハーフタイム
*/
int
l_getnrExtraHalfs()
{
    return ServerParam::i().nrExtraHalfs();
}

/** \fn openFile
*   \brief Luaファイルを開く
*/
void
SParamFunction::openFile()
{

}


/** \fn bindFunc
*   \brief 関数のバインドを行う
*/
void
SParamFunction::bindFunc()
{
    // 関数やクラスを登録
    module(Luas)
    [
        def("getBallSize", &l_getBallSize),
        def("getPower", &l_getPower),
        def("oppGoalPosX", &l_oppGoalPosX),
        def("oppGoalPosY", &l_oppGoalPosY),
	def("maxNeckAngle", &l_maxNeckAngle),
	def("getcenterCircleR", &l_getcenterCircleR),
	def("getgoalHalfWidth", &l_getgoalHalfWidth),
	def("getcatchableArea", &l_getcatchableArea),
	def("pitchHalfLength", &l_pitchHalfLength),
	def("ourPenaltyAreaLineX", &l_ourPenaltyAreaLineX),
	def("theirPenaltyAreaLineX", &l_theirPenaltyAreaLineX),
	def("penaltyAreaHalfWidth", &l_penaltyAreaHalfWidth),
	def("getHalfTime", &l_getHalfTime),
	def("getExtraHalfTime", &l_getExtraHalfTime),
	def("getnrNormalHalfs", &l_getnrNormalHalfs),
	def("getnrExtraHalfs", &l_getnrExtraHalfs),
	def("iskickoffOffside", &l_iskickoffOffside)
    ];
}
